==> jc-1.4.0.tar.gz: soot/tagkit/LinkTag.h <==
// public class soot.tagkit.LinkTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c4ab109569c6338c soot_tagkit_LinkTag
// @dep_class 25504195378c79cb soot_tagkit_StringTag

// header file dependencies
// @dep_header soot_tagkit_StringTag

#include "soot/tagkit/StringTag.h"

#ifndef _JC_soot_tagkit_LinkTag_H_
#define _JC_soot_tagkit_LinkTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_tagkit_Host$object;

// Typedefs
typedef struct _jc_soot_tagkit_LinkTag$sub_refs	_jc_soot_tagkit_LinkTag$sub_refs;
typedef struct _jc_soot_tagkit_LinkTag$sub_nonrefs	_jc_soot_tagkit_LinkTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_LinkTag$refs	_jc_soot_tagkit_LinkTag$refs;
typedef struct _jc_soot_tagkit_LinkTag$nonrefs	_jc_soot_tagkit_LinkTag$nonrefs;
typedef struct _jc_soot_tagkit_LinkTag$object	_jc_soot_tagkit_LinkTag$object;

typedef const struct _jc_soot_tagkit_LinkTag$vmethods	_jc_soot_tagkit_LinkTag$vmethods;
typedef const struct _jc_soot_tagkit_LinkTag$vtable	_jc_soot_tagkit_LinkTag$vtable;
typedef const struct _jc_soot_tagkit_LinkTag$vtype	_jc_soot_tagkit_LinkTag$vtype;

// Constructors
extern void _jc_soot_tagkit_LinkTag$method$_init$b479e314bd155ed5(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_LinkTag$method$getClassName$333433582f896913(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *);
extern struct _jc_object *_jc_soot_tagkit_LinkTag$method$getLink$7eda97d325feed60(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_LinkTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *);
extern _jc_byte_array *_jc_soot_tagkit_LinkTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_LinkTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_LinkTag$method_info$getClassName$333433582f896913;
extern _jc_method _jc_soot_tagkit_LinkTag$method_info$getLink$7eda97d325feed60;
extern _jc_method _jc_soot_tagkit_LinkTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_LinkTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_LinkTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_LinkTag$vmethods {
	struct _jc_java_lang_String$object	*(*getClassName$333433582f896913)(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *);
	struct _jc_object	*(*getLink$7eda97d325feed60)(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *);
};

// Vtable
struct _jc_soot_tagkit_LinkTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_StringTag$vmethods	soot_tagkit_StringTag;
	_jc_soot_tagkit_LinkTag$vmethods	soot_tagkit_LinkTag;
};

// Vtype
struct _jc_soot_tagkit_LinkTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_LinkTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_LinkTag$sub_refs {
	struct _jc_object	*link;
	struct _jc_java_lang_String$object	*className;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_LinkTag$refs {
    _jc_soot_tagkit_LinkTag$sub_refs	soot_tagkit_LinkTag;
    _jc_soot_tagkit_StringTag$sub_refs	soot_tagkit_StringTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_LinkTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_LinkTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_StringTag$sub_nonrefs	soot_tagkit_StringTag;
    _jc_soot_tagkit_LinkTag$sub_nonrefs	soot_tagkit_LinkTag;
};

// Object instance structure
struct _jc_soot_tagkit_LinkTag$object {
	_jc_soot_tagkit_LinkTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_LinkTag$vtype	*vtype;
	_jc_soot_tagkit_LinkTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_LinkTag$vtype _jc_soot_tagkit_LinkTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_LinkTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_LinkTag$class_object;

#endif	/* _JC_soot_tagkit_LinkTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/LinkTag.h <==
// public class soot.tagkit.LinkTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c4ab109569c6338c soot_tagkit_LinkTag
// @dep_class 25504195378c79cb soot_tagkit_StringTag

// header file dependencies
// @dep_header soot_tagkit_StringTag

#include "soot/tagkit/StringTag.h"

#ifndef _JC_soot_tagkit_LinkTag_H_
#define _JC_soot_tagkit_LinkTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_tagkit_Host$object;

// Typedefs
typedef struct _jc_soot_tagkit_LinkTag$sub_refs	_jc_soot_tagkit_LinkTag$sub_refs;
typedef struct _jc_soot_tagkit_LinkTag$sub_nonrefs	_jc_soot_tagkit_LinkTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_LinkTag$refs	_jc_soot_tagkit_LinkTag$refs;
typedef struct _jc_soot_tagkit_LinkTag$nonrefs	_jc_soot_tagkit_LinkTag$nonrefs;
typedef struct _jc_soot_tagkit_LinkTag$object	_jc_soot_tagkit_LinkTag$object;

typedef const struct _jc_soot_tagkit_LinkTag$vmethods	_jc_soot_tagkit_LinkTag$vmethods;
typedef const struct _jc_soot_tagkit_LinkTag$vtable	_jc_soot_tagkit_LinkTag$vtable;
typedef const struct _jc_soot_tagkit_LinkTag$vtype	_jc_soot_tagkit_LinkTag$vtype;

// Constructors
extern void _jc_soot_tagkit_LinkTag$method$_init$b479e314bd155ed5(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_LinkTag$method$getClassName$333433582f896913(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_tagkit_LinkTag$method$getLink$7eda97d325feed60(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_LinkTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_LinkTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_LinkTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_LinkTag$method_info$getClassName$333433582f896913;
extern _jc_method _jc_soot_tagkit_LinkTag$method_info$getLink$7eda97d325feed60;
extern _jc_method _jc_soot_tagkit_LinkTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_LinkTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_LinkTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_LinkTag$vmethods {
	struct _jc_java_lang_String$object	*(*getClassName$333433582f896913)(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLink$7eda97d325feed60)(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_LinkTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_LinkTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_StringTag$vmethods	soot_tagkit_StringTag;
	_jc_soot_tagkit_LinkTag$vmethods	soot_tagkit_LinkTag;
};

// Vtype
struct _jc_soot_tagkit_LinkTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_LinkTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_LinkTag$sub_refs {
	struct _jc_object	*link;
	struct _jc_java_lang_String$object	*className;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_LinkTag$refs {
    _jc_soot_tagkit_LinkTag$sub_refs	soot_tagkit_LinkTag;
    _jc_soot_tagkit_StringTag$sub_refs	soot_tagkit_StringTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_LinkTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_LinkTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_StringTag$sub_nonrefs	soot_tagkit_StringTag;
    _jc_soot_tagkit_LinkTag$sub_nonrefs	soot_tagkit_LinkTag;
};

// Object instance structure
struct _jc_soot_tagkit_LinkTag$object {
	_jc_soot_tagkit_LinkTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_LinkTag$vtype	*vtype;
	_jc_soot_tagkit_LinkTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_LinkTag$vtype _jc_soot_tagkit_LinkTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_LinkTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_LinkTag$class_object;

#endif	/* _JC_soot_tagkit_LinkTag_H_ */
